@@ -18,7 +18,18 @@ def call_run_subprocess(file, args=None):
 def run_code(project_dir, entry_point, debug=False):
 	files = list_files(project_dir)
 	entry_point_file = ''
-	entry_point = f"{entry_point}.py"
+	
+	entry_point_splitted = entry_point.split(".")
+
+	if len(entry_point_splitted) > 1:
+		if entry_point_splitted[1] == "py":
+			entry_point = f"{entry_point}"
+		else
+			entry_point = f"{entry_point_splitted[0]}.py"
+	else:
+		entry_point = f"{entry_point_splitted[0]}.py"
+		
+
 	for file in files:
 		if entry_point in file:
 			entry_point_file += file
